<?php
/**
 * Slider Section options
 *
 * @package Theme Palace
 * @subpackage  ultra_gym
 * @since  ultra_gym 1.0.0
 */

// Add Slider section
$wp_customize->add_section( 'ultra_gym_slider_section', array(
	'title'             => esc_html__( 'Slider','ultra-gym' ),
	'description'       => esc_html__( 'Slider Section options.', 'ultra-gym' ),
	'panel'             => 'ultra_gym_front_page_panel',
) );

// Slider content enable control and setting
$wp_customize->add_setting( 'ultra_gym_theme_options[slider_section_enable]', 
	array(
		'default'			=> 	$options['slider_section_enable'],
		'sanitize_callback' => 'ultra_gym_sanitize_switch_control',
	) 
);

$wp_customize->add_control( new Ultra_Gym_Switch_Control( $wp_customize, 'ultra_gym_theme_options[slider_section_enable]',
	array(
		'label'             => esc_html__( 'Slider Section Enable', 'ultra-gym' ),
		'section'           => 'ultra_gym_slider_section',
		'on_off_label' 		=> ultra_gym_switch_options(),
	)
) );

// Slider autoplay enable control and setting
$wp_customize->add_setting( 'ultra_gym_theme_options[slider_autoplay_enable]',
	array(
		'default'			=> 	$options['slider_autoplay_enable'],
		'sanitize_callback' => 'ultra_gym_sanitize_switch_control',
	)
);

$wp_customize->add_control( new Ultra_Gym_Switch_Control( $wp_customize, 'ultra_gym_theme_options[slider_autoplay_enable]',
	array(
		'label'             => esc_html__( 'Slider Autoplay Enable', 'ultra-gym' ),
		'section'           => 'ultra_gym_slider_section',
		'active_callback'   => 'ultra_gym_is_slider_section_enable',
		'on_off_label' 		=> ultra_gym_switch_options(),
	)
) );

// Slider Social Menu enable control and setting
$wp_customize->add_setting( 'ultra_gym_theme_options[slider_social_menu_enable]',
	array(
		'default'			=> 	$options['slider_social_menu_enable'],
		'sanitize_callback' => 'ultra_gym_sanitize_switch_control',
	)
);

$wp_customize->add_control( new Ultra_Gym_Switch_Control( $wp_customize, 'ultra_gym_theme_options[slider_social_menu_enable]',
	array(
		'label'             => esc_html__( 'Show Social Menu', 'ultra-gym' ),
		'section'           => 'ultra_gym_slider_section',
		'active_callback'   => 'ultra_gym_is_slider_section_enable',
		'on_off_label' 		=> ultra_gym_switch_options(),
	)
) );


for ( $i = 1; $i <= 3; $i++ ) :

	// slider pages drop down chooser control and setting
	$wp_customize->add_setting( 'ultra_gym_theme_options[slider_content_page_'.$i.']', 
		array(
			'sanitize_callback' => 'ultra_gym_sanitize_page',
		)
	);

	$wp_customize->add_control( new Ultra_Gym_Dropdown_Chooser( $wp_customize, 'ultra_gym_theme_options[slider_content_page_'.$i.']', 
		array(
			'label'             => sprintf(esc_html__( 'Select Page : %d', 'ultra-gym'), $i ),
			'section'           => 'ultra_gym_slider_section',
			'choices'			=> ultra_gym_page_choices(),
			'active_callback'	=> 'ultra_gym_is_slider_section_enable',
		)
	) );

	// ultra_gym_Customize_Horizontal_Line
    $wp_customize->add_setting('ultra_gym_theme_options[slider_separator_'.$i.']',
		array(
			'sanitize_callback'      => 'ultra_gym_sanitize_html',
		)
	);

    $wp_customize->add_control(new Ultra_Gym_Customize_Horizontal_Line($wp_customize,'ultra_gym_theme_options[slider_separator_'.$i.']',
	array(
			'active_callback'       => 'ultra_gym_is_slider_section_enable',
			'type'                  =>'hr',
			'section'               =>'ultra_gym_slider_section',
		)
	));

endfor;


//slider_btn_txt
$wp_customize->add_setting('ultra_gym_theme_options[slider_btn_txt]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'			=> 'postMessage',
        'default'           => $options['slider_btn_txt'],
    )
);

$wp_customize->add_control('ultra_gym_theme_options[slider_btn_txt]',
    array(
        'section'			=> 'ultra_gym_slider_section',
        'label'				=> esc_html__( 'Button Text:', 'ultra-gym' ),
        'type'          	=>'text',
        'active_callback' 	=> 'ultra_gym_is_slider_section_enable'
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'ultra_gym_theme_options[slider_btn_txt]',
		array(
			'selector'            => '#featured-slider article div.read-more a:nth-child(1)',
			'settings'            => 'ultra_gym_theme_options[slider_btn_txt]',
			'fallback_refresh'    => true,
			'container_inclusive' => false,
			'render_callback'     => 'ultra_gym_slider_btn_txt_partial',
		) 
	);
}
