<?php

/**
 * Testimonial Section options
 *
 * @package Theme Palace
 * @subpackage  ultra_gym
 * @since  ultra_gym 1.0.0
 */

// Add Testimonial section
$wp_customize->add_section('ultra_gym_testimonial_section', array(
    'title'         => esc_html__('Testimonials', 'ultra-gym'),
    'description'   => esc_html__('Testimonials Section options.', 'ultra-gym'),
    'panel'         => 'ultra_gym_front_page_panel',
));

// Testimonial content enable control and setting
$wp_customize->add_setting('ultra_gym_theme_options[testimonial_section_enable]', array(
    'default'           => $options['testimonial_section_enable'],
    'sanitize_callback' => 'ultra_gym_sanitize_switch_control',
));

$wp_customize->add_control(new Ultra_Gym_Switch_Control($wp_customize, 'ultra_gym_theme_options[testimonial_section_enable]', array(
    'label'         => esc_html__('Testimonial Section Enable', 'ultra-gym'),
    'section'       => 'ultra_gym_testimonial_section',
    'on_off_label'  => ultra_gym_switch_options(),
)));

// Testimonial section sub title control and setting
$wp_customize->add_setting('ultra_gym_theme_options[testimonial_section_sub_title]', array(
    'sanitize_callback'     => 'sanitize_text_field',
    'transport'             => 'postMessage',
    'default'               => $options['testimonial_section_sub_title'],
));

$wp_customize->add_control('ultra_gym_theme_options[testimonial_section_sub_title]', array(
    'label'             => esc_html__('Section Sub Title', 'ultra-gym'),
    'section'           => 'ultra_gym_testimonial_section',
    'type'              => 'text',
    'active_callback'   => 'ultra_gym_is_testimonial_section_enable',
));
$wp_customize->selective_refresh->add_partial('ultra_gym_theme_options[testimonial_section_sub_title]', array(
    'selector'          => '#testimonial .section-subtitle',
    'render_callback'   => 'ultra_gym_testimonial_section_partial_sub_title',
    )
);

// Testimonial section title control and setting
$wp_customize->add_setting('ultra_gym_theme_options[testimonial_section_title]', array(
    'default'               => $options['testimonial_section_title'],
    'sanitize_callback'     => 'sanitize_text_field',
    'transport'             => 'postMessage'
));

$wp_customize->add_control('ultra_gym_theme_options[testimonial_section_title]', array(
    'label'                 => esc_html__('Section Title', 'ultra-gym'),
    'section'               => 'ultra_gym_testimonial_section',
    'type'                  => 'text',
    'active_callback'       => 'ultra_gym_is_testimonial_section_enable',
));
$wp_customize->selective_refresh->add_partial('ultra_gym_theme_options[testimonial_section_title]', array(
        'selector'          => '#testimonial .section-title',
        'render_callback'   => 'ultra_gym_testimonial_section_partial_title',
    )
);


for ($i = 1; $i <= 4; $i++):
// Testimonial pages drop down chooser control and setting
    $wp_customize->add_setting('ultra_gym_theme_options[testimonial_content_page_' . $i . ']', array(
        'sanitize_callback' => 'ultra_gym_sanitize_page',
    ));

    $wp_customize->add_control(new Ultra_Gym_Dropdown_Chooser($wp_customize, 'ultra_gym_theme_options[testimonial_content_page_' . $i . ']', array(
        'label'             => sprintf(esc_html__('Select Page : %d', 'ultra-gym'), $i),
        'section'           => 'ultra_gym_testimonial_section',
        'choices'           => ultra_gym_page_choices(),
        'active_callback'   => 'ultra_gym_is_testimonial_section_enable',
    )));

    // Testimonial posts sub title control and setting
    $wp_customize->add_setting('ultra_gym_theme_options[testimonial_post_designation_' . $i . ']', array(
        'sanitize_callback' => 'sanitize_text_field',
    ));

    $wp_customize->add_control(new Ultra_Gym_Dropdown_Chooser($wp_customize, 'ultra_gym_theme_options[testimonial_post_designation_' . $i . ']', array(
        'label'             => sprintf(esc_html__('Select Designation : %d', 'ultra-gym'), $i),
        'section'           => 'ultra_gym_testimonial_section',
        'active_callback'   => 'ultra_gym_is_testimonial_section_enable',
        'type'              => 'text',
    )));

    //testimonial separator
    $wp_customize->add_setting('ultra_gym_theme_options[testimonial_separator'. $i .']',array(
        'sanitize_callback'      => 'ultra_gym_sanitize_html',
    ));

    $wp_customize->add_control(new Ultra_Gym_Customize_Horizontal_Line($wp_customize,'ultra_gym_theme_options[testimonial_separator'. $i .']',array(
        'active_callback'       => 'ultra_gym_is_testimonial_section_enable',
        'type'                  =>'hr',
        'section'               =>'ultra_gym_testimonial_section',
    )));

endfor;

$wp_customize->add_setting( 'ultra_gym_theme_options[testimonial_bg_image]',
    array(
        'sanitize_callback' => 'ultra_gym_sanitize_image',
    ) 
);

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'ultra_gym_theme_options[testimonial_bg_image]',
    array(
        'label'       		=> esc_html__( 'Background Image', 'ultra-gym' ),
        'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'ultra-gym' ), 1350, 385 ),
        'section'     		=> 'ultra_gym_testimonial_section',
        'active_callback'	=> 'ultra_gym_is_testimonial_section_enable',
    )
) );
