<?php
/**
 * Blog section
 *
 * This is the template for the content of blog section
 *
 * @package Theme Palace
 * @subpackage  ultra_gym
 * @since  ultra_gym 1.0.0
 */
if ( ! function_exists( 'ultra_gym_add_blog_section' ) ) :
    /**
    * Add blog section
    *
    *@since  ultra_gym 1.0.0
    */
    function ultra_gym_add_blog_section() {
        $options = ultra_gym_get_theme_options();
        // Check if blog is enabled on frontpage
        $blog_enable = apply_filters( 'ultra_gym_section_status', true, 'blog_section_enable' );

        if ( true !== $blog_enable ) {
            return false;
        }
        // Get blog section details
        $section_details = array();
        $section_details = apply_filters( 'ultra_gym_filter_blog_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }
        // Render blog section now.
        ultra_gym_render_blog_section( $section_details );
    }
endif;

if ( ! function_exists( 'ultra_gym_get_blog_section_details' ) ) :
    /**
    * blog section details.
    *
    * @since  ultra_gym 1.0.0
    * @param array $input blog section details.
    */
    function ultra_gym_get_blog_section_details( $input ) {
        $options = ultra_gym_get_theme_options();

        $content = array();
         
        $cat_id = ! empty( $options['blog_content_category'] ) ? $options['blog_content_category'] : '';
        $args = array(
            'post_type'             => 'post',
            'posts_per_page'        => 4,
            'cat'                   => absint( $cat_id ),
            'ignore_sticky_posts'   => true,
            );                    

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['author_id'] = get_the_author_meta('ID');
                $page_post['excerpt']   = ultra_gym_trim_content( 30);
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';
                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// blog section content details.
add_filter( 'ultra_gym_filter_blog_section_details', 'ultra_gym_get_blog_section_details' );


if ( ! function_exists( 'ultra_gym_render_blog_section' ) ) :
  /**
   * Start blog section
   *
   * @return string blog content
   * @since  ultra_gym 1.0.0
   *
   */
   function ultra_gym_render_blog_section( $content_details = array() ) {
        $options                = ultra_gym_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="ultra_gym_blog_section">
             <div id="blog" class="page-section">
                <div class="wrapper">
                    <div class="section-header">
                        <p class="section-subtitle"><?php echo esc_html($options['blog_sub_title'])?></p>
                        <h2 class="section-title"><?php echo esc_html($options['blog_title'])?></h2>
                    </div><!-- .section-header -->

                    <div class="section-content">
                        <div class="archive-blog-wrapper">

                            <?php foreach ($content_details as $content):?>
                            <article class="has-post-thumbnail">
                                <div class="featured-image" style="background-image: url('<?php echo esc_url($content['image']);?>');">
                                    <a href="<?php echo esc_url($content['url']);?>" class="post-thumbnail-link" title="<?php echo esc_attr($content['title']); ?>"></a>
                                </div><!-- .featured-image -->

                                <div class="entry-container">
                                    <span class="cat-links">
                                        <ul class="post-categories">
                                            <?php the_category(',', '', $content['id']); ?>
                                        </ul>
                                    </span>

                                    <header class="entry-header">
                                       <h2 class="entry-title"><a href="<?php echo esc_url($content['url']); ?>" tabindex="0"><?php echo esc_html($content['title']); ?></a></h2>
                                    </header>

                                    <div class="entry-content">
                                       <p><?php echo wp_kses_post($content['excerpt']);?></p>
                                    </div><!-- .entry-content -->

                                    <?php if(!empty($options['blog_post_read_more_btn_label'])) : ?>
                                    <div class="more-link">
                                        <a href="<?php echo esc_url($content['url']); ?>" tabindex="0"><?php echo esc_html($options['blog_post_read_more_btn_label']); ?></a>
                                    </div>
                                    <?php endif; ?>

                                    <div class="entry-meta">
                                        <?php 
                                        ultra_gym_posted_on($content['id']);
                                        echo ultra_gym_author($content['author_id']); ?>
                                    </div><!-- .entry-meta -->
                                </div><!-- .entry-container -->
                            </article>
                            <?php endforeach; ?>

                        </div><!-- .archive -->
                    </div><!-- .section-content -->
                </div><!-- .wrapper -->
            </div><!-- .blog -->
        </div>
           
    <?php }
endif;  ?>
