<?php
/**
 * Banner section
 *
 * This is the template for the content of slider section
 *
 * @package Theme Palace
 * @subpackage  ultra_gym
 * @since  ultra_gym 1.0.0
 */
if ( ! function_exists( 'ultra_gym_add_slider_section' ) ) :
    /**
    * Add slider section
    *
    *@since  ultra_gym 1.0.0
    */
    function ultra_gym_add_slider_section() {
    	$options = ultra_gym_get_theme_options();
        // Check if slider is enabled on frontpage
        $slider_enable = apply_filters( 'ultra_gym_section_status', true, 'slider_section_enable' );

        if ( true !== $slider_enable ) {
            return false;
        }
        // Get slider section details
        $section_details = array();
        $section_details = apply_filters( 'ultra_gym_filter_slider_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render slider section now.
        ultra_gym_render_slider_section( $section_details );
}

endif;

if ( ! function_exists( 'ultra_gym_get_slider_section_details' ) ) :
    /**
    * slider section details.
    *
    * @since  ultra_gym 1.0.0
    * @param array $input slider section details.
    */
    function ultra_gym_get_slider_section_details( $input ) {
        $options = ultra_gym_get_theme_options();

        $content = array();
        $page_ids = array();

        for ( $i = 1; $i <= 3; $i++ ) {
            if ( ! empty( $options['slider_content_page_'.$i] ) )
                $page_ids[] = $options['slider_content_page_'.$i];
        }

        $args = array(
            'post_type'         => 'page',
            'post__in'          => ( array ) $page_ids,
            'posts_per_page'    => 3,
            'orderby'           => 'post__in',
            );                    

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = ultra_gym_trim_content(15);
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : '';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// slider section content details.
add_filter( 'ultra_gym_filter_slider_section_details', 'ultra_gym_get_slider_section_details' );


if ( ! function_exists( 'ultra_gym_render_slider_section' ) ) :
  /**
   * Start slider section
   *
   * @return string slider content
   * @since  ultra_gym 1.0.0
   *
   */
   function ultra_gym_render_slider_section( $content_details = array() ) {
        $options = ultra_gym_get_theme_options();
        $slider_autoplay_enable = ($options['slider_autoplay_enable']) ? 'true' : 'false';

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="ultra_gym_slider_section">
              <div id="featured-slider" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 800, "dots": true, "arrows": true, "autoplay": <?php echo esc_attr($slider_autoplay_enable); ?>, "draggable": true, "fade": false }'>
                <?php foreach ( $content_details as $content ) : ?>
                <article style="background-image:url('<?php echo $content['image']; ?>');">
                    <div class="overlay" style='opacity: 0;'></div>
                    <div class="wrapper">
                        <div class="featured-content-wrapper">
                            <div class="entry-container">  
                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                </header>

                                <div class="entry-content">
                                    <p><?php echo wp_kses_post($content['excerpt']); ?></p>
                                </div><!-- .entry-content-->

                                <?php if(!empty($options['slider_btn_txt'])): ?>
                                    <div class="read-more">
                                        <a href="<?php echo esc_url($content['url']); ?>" class="btn"><?php echo esc_html($options['slider_btn_txt']); ?></a>
                                    </div><!-- .read-more -->
                                <?php endif; ?>
                            </div> 

                        <?php  
                            if(has_nav_menu( 'social' ) && $options['slider_social_menu_enable']):
                
                                wp_nav_menu(  array(
                                    'theme_location' => 'social',
                                    'container' => 'div',
                                    'container_class' => 'social-icons',
                                    'echo' => true,
                                    'depth' => 1,
                                    'link_before' => '<span class="screen-reader-text">',
                                    'link_after' => '</span>',
                                    'fallback_cb' => false,
                                ) );
                                
                            endif; ?>

                        </div><!-- .featured-content-wrapper -->
                    </div><!-- .wrapper -->
                </article>
                <?php endforeach; ?>

            </div><!-- #featured-slider -->
        </div>
          
    <?php
    }    
endif;

