<?php
/**
 * Theme Palace basic theme structure hooks
 *
 * This file contains structural hooks.
 *
 * @package Theme Palace
 * @subpackage  ultra_gym
 * @since  ultra_gym 1.0.0
 */

$options = ultra_gym_get_theme_options();  


if ( ! function_exists( 'ultra_gym_doctype' ) ) :
	/**
	 * Doctype Declaration.
	 *
	 * @since  ultra_gym 1.0.0
	 */
	function ultra_gym_doctype() {
	?>
		<!DOCTYPE html>
			<html <?php language_attributes(); ?>>
	<?php
	}
endif;
add_action( 'ultra_gym_doctype', 'ultra_gym_doctype', 10 );


if ( ! function_exists( 'ultra_gym_head' ) ) :
	/**
	 * Header Codes
	 *
	 * @since  ultra_gym 1.0.0
	 *
	 */
	function ultra_gym_head() {
		?>
		<meta charset="<?php bloginfo( 'charset' ); ?>">
		<meta name="viewport" content="width=device-width, initial-scale=1">
		<link rel="profile" href="https://gmpg.org/xfn/11">
		<?php if ( is_singular() && pings_open( get_queried_object() ) ) : ?>
			<link rel="pingback" href="<?php echo esc_url( get_bloginfo( 'pingback_url' ) ); ?>">
		<?php endif;
	}
endif;
add_action( 'ultra_gym_before_wp_head', 'ultra_gym_head', 10 );

if ( ! function_exists( 'ultra_gym_page_start' ) ) :
	/**
	 * Page starts html codes
	 *
	 * @since  ultra_gym 1.0.0
	 *
	 */
	function ultra_gym_page_start() {
		?>
		<div id="page" class="site">
			<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'ultra-gym' ); ?></a>

		<?php
	}
endif;
add_action( 'ultra_gym_page_start_action', 'ultra_gym_page_start', 10 );

if ( ! function_exists( 'ultra_gym_page_end' ) ) :
	/**
	 * Page end html codes
	 *
	 * @since  ultra_gym 1.0.0
	 *
	 */
	function ultra_gym_page_end() {
		?>
		</div><!-- #page -->
		<?php
	}
endif;
add_action( 'ultra_gym_page_end_action', 'ultra_gym_page_end', 10 );

if ( ! function_exists( 'ultra_gym_site_branding' ) ) :
	/**
	 * Site branding codes
	 *
	 * @since  ultra_gym 1.0.0
	 *
	 */
	function ultra_gym_site_branding() {
		$options  = ultra_gym_get_theme_options();
		$header_txt_logo_extra = $options['header_txt_logo_extra'];	?>

		<div class="menu-overlay"></div>
		<div id="site-menu" class="header-menu">
			<header id="masthead" class="site-header" role="banner">
				<div class="wrapper">
					<div class="site-menu">
	
						<div class="site-branding">
							<?php if ( in_array( $header_txt_logo_extra, array( 'show-all', 'logo-title', 'logo-tagline' ) ) && has_custom_logo()  ) : ?>
								<div class="site-logo">
									<?php the_custom_logo(); ?>
								</div>
							<?php endif; 

							if ( in_array( $header_txt_logo_extra, array( 'show-all', 'title-only', 'logo-title', 'show-all', 'tagline-only', 'logo-tagline' ) ) ) : ?>
								<div id="site-identity">
									<?php
									if( in_array( $header_txt_logo_extra, array( 'show-all', 'title-only', 'logo-title' ) )  ) {
										if ( ultra_gym_is_latest_posts() || ultra_gym_is_frontpage() ) : ?>
											<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
										<?php else : ?>
											<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
										<?php
										endif;
									} 
									if ( in_array( $header_txt_logo_extra, array( 'show-all', 'tagline-only', 'logo-tagline' ) ) ) {
										$description = get_bloginfo( 'description', 'display' );
										if ( $description || is_customize_preview() ) : ?>
											<p class="site-description"><?php echo esc_html( $description ); /* WPCS: xss ok. */ ?></p>
										<?php
										endif; 
									}?>
								</div>
							<?php endif; ?>
						</div><!-- .site-branding -->

						<nav id="site-navigation" class="main-navigation" role="navigation" aria-label="Primary Menu">
							<button class="menu-toggle" aria-controls="primary-menu" aria-expanded="false" title="Primary Menu">
							<?php
							echo ultra_gym_get_svg( array( 'icon' => 'menu', 'class' => 'icon-menu' ) );
							echo ultra_gym_get_svg( array( 'icon' => 'close', 'class' => 'icon-menu' ) );
							?>		
							<span class="menu-label"><?php esc_html_e('Menu', 'ultra-gym'); ?></span>		
							</button>
							<?php  
								wp_nav_menu( array(
									'theme_location' => 'primary',
									'container' => 'div',
									'menu_class' => 'menu nav-menu',
									'menu_id' => 'primary-menu',
									'echo' => true,
									'fallback_cb' => 'ultra_gym_menu_fallback_cb',
								) );
							?>
						</nav><!-- #site-navigation -->
					</div><!-- .site-menu -->
					
					<div class="login">
                        <a href="#">
                            <?php echo get_avatar( get_option( 'admin_email' ) ) ?>
                        </a>
                    </div>
				</div><!-- .wrapper -->
			</header><!-- .header-->
		</div><!-- .header-menu -->
        <?php 
	}
endif;
add_action( 'ultra_gym_header_action', 'ultra_gym_site_branding', 10 );

if ( ! function_exists( 'ultra_gym_content_start' ) ) :
	/**
	 * Site content codes
	 *
	 * @since  ultra_gym 1.0.0
	 *
	 */
	function ultra_gym_content_start() {
		?>
		<div id="content" class="site-content">
		<?php
	}
endif;
add_action( 'ultra_gym_content_start_action', 'ultra_gym_content_start', 10 );

if ( ! function_exists( 'ultra_gym_header_image' ) ) :
    /**
     * Header Image codes
     *
     * @since  ultra_gym 1.0.0
     *
     */
    function ultra_gym_header_image() {
        if ( ultra_gym_is_frontpage() )
            return;
        $header_image = get_header_image();
        if ( is_singular() ) :
            $header_image = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : $header_image;
        endif;
        ?>

        <div id="page-site-header" class="relative" style="background-image: url('<?php echo esc_url( $header_image ); ?>');">
            <div class="overlay" style="opacity:0.4;"></div>
            <div class="wrapper">
                <header class="page-header">
                    <?php ultra_gym_custom_header_banner_title(); ?>
                </header>
                <?php ultra_gym_add_breadcrumb(); ?>
            </div>
        </div><!-- #page-site-header -->

        <?php
    }
endif;
add_action( 'ultra_gym_header_image_action', 'ultra_gym_header_image', 10 );

if ( ! function_exists( 'ultra_gym_add_breadcrumb' ) ) :
	/**
	 * Add breadcrumb.
	 *
	 * @since  ultra_gym 1.0.0
	 */
	function ultra_gym_add_breadcrumb() {
		$options = ultra_gym_get_theme_options();

		// Bail if Breadcrumb disabled.
		$breadcrumb = $options['breadcrumb_enable'];
		if ( false === $breadcrumb ) {
			return;
		}
		
		// Bail if Home Page.
		if ( ultra_gym_is_frontpage() ) {
			return;
		}

		echo '<div id="breadcrumb-list" >';
				/**
				 * ultra_gym_simple_breadcrumb hook
				 *
				 * @hooked ultra_gym_simple_breadcrumb -  10
				 *
				 */
				do_action( 'ultra_gym_simple_breadcrumb' );
		echo '</div><!-- #breadcrumb-list -->';
	}
endif;

if ( ! function_exists( 'ultra_gym_content_end' ) ) :
	/**
	 * Site content codes
	 *
	 * @since  ultra_gym 1.0.0
	 *
	 */
	function ultra_gym_content_end() {
		?>
        </div><!-- #content -->
		<?php
	}
endif;
add_action( 'ultra_gym_content_end_action', 'ultra_gym_content_end', 10 );

if ( ! function_exists( 'ultra_gym_footer_start' ) ) :
	/**
	 * Footer starts
	 *
	 * @since  ultra_gym 1.0.0
	 *
	 */
	function ultra_gym_footer_start() {
		?>
		<footer id="colophon" class="site-footer" role="contentinfo">
		<?php
	}
endif;
add_action( 'ultra_gym_footer', 'ultra_gym_footer_start', 10 );

if ( ! function_exists( 'ultra_gym_footer_site_info' ) ) :
	/**
	 * Footer starts
	 *
	 * @since  ultra_gym 1.0.0
	 *
	 */
	function ultra_gym_footer_site_info() {
		$options = ultra_gym_get_theme_options();
		$search = array( '[the-year]', '[site-link]' );

        $replace = array( date( 'Y' ), '<a href="'. esc_url( home_url( '/' ) ) .'">'. esc_attr( get_bloginfo( 'name', 'display' ) ) . '</a>' );

        $options['copyright_text'] = str_replace( $search, $replace, $options['copyright_text'] );

		$copyright_text = $options['copyright_text'];
		?>
		<div class="site-info">
                <div class="wrapper">
				<?php  
					if(has_nav_menu( 'social' )):
		
						wp_nav_menu(  array(
							'theme_location' => 'social',
							'container' => 'div',
							'container_class' => 'social-icons',
							'echo' => true,
							'depth' => 1,
							'link_before' => '<span class="screen-reader-text">',
							'link_after' => '</span>',
							'fallback_cb' => false,
						) );
						
				endif; ?>
                    <span>
                    <?php 
	                	echo ultra_gym_santize_allow_tag( $copyright_text ); 
	                	if ( function_exists( 'the_privacy_policy_link' ) ) {
							the_privacy_policy_link( ' | ' );
						}
                	?>
                	</span>
                </div><!-- .wrapper -->    
            </div><!-- .site-info -->

		<?php
	}
endif;
add_action( 'ultra_gym_footer', 'ultra_gym_footer_site_info', 40 );


if ( ! function_exists( 'ultra_gym_infinite_loader_spinner' ) ) :
	/**
	 *
	 * @since  ultra_gym 1.0.0
	 *
	 */
	function ultra_gym_infinite_loader_spinner() { 
		global $post;
		$options = ultra_gym_get_theme_options();
		if ( $options['pagination_type'] == 'infinite' ) :			
			echo '<div class="blog-loader">' . ultra_gym_get_svg( array( 'icon' => 'spinner-umbrella' ) ) . '</div>';			
		endif;
	}
endif;
add_action( 'ultra_gym_infinite_loader_spinner_action', 'ultra_gym_infinite_loader_spinner', 10 );
